============
Installation
============

At the command line::

    $ pip install networking-bgpvpn

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv networking-bgpvpn
    $ pip install networking-bgpvpn

=============
Configuration
=============

TBC (notes on driver configuration in /etc/neutron/networking_bgpvpn.conf and policy.json)

==============
Database setup
==============

TBC (notes on DB creation & migration tool)


